unit main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, IniFiles, StdCtrls, SHFolder, InvokeRegistry, Rio,
  SOAPHTTPClient, send, ExtCtrls;

type
  TSmsCreator_MainForm = class(TForm)
    GroupBox1: TGroupBox;
    User_Edit: TEdit;
    Pw_Edit: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Test_Button: TButton;
    HTTPRIO1: THTTPRIO;
    Log_Memo: TMemo;
    GroupBox2: TGroupBox;
    Rec_Memo: TMemo;
    Label3: TLabel;
    Caption_Edit: TEdit;
    Msg_Memo: TMemo;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Sender_Edit: TEdit;
    Label7: TLabel;
    Status_Panel: TPanel;
    Send_Button: TButton;
    Simple_CB: TCheckBox;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure Test_ButtonClick(Sender: TObject);
    procedure HTTPRIO1BeforeExecute(const MethodName: String;
      var SOAPRequest: WideString);
    procedure HTTPRIO1AfterExecute(const MethodName: String;
      SOAPResponse: TStream);
    procedure Send_ButtonClick(Sender: TObject);
    procedure Simple_CBClick(Sender: TObject);
  private
    IniUser,
    IniPw,
    IniRecipients,
    IniCaption,
    IniMsg,
    IniSender,
    IniDir : string;
    IniSimple : boolean;
    procedure ReadIniF;
    procedure WriteIniF;
    procedure DoAddLogMemo(sLog: string);
    procedure DoSimpleCheck;

  public
    { Public-Deklarationen }
  end;

var
  SmsCreator_MainForm: TSmsCreator_MainForm;

implementation

{$R *.dfm}
const
  cIniFile = 'smscr.ini';
  cIniDir  = 'SmsCreator\';

function GetSpecialFolderPath(folder : integer) : string;
const
   SHGFP_TYPE_CURRENT = 0;
var
   path: array [0..MAX_PATH] of char;
begin
   if SUCCEEDED(SHGetFolderPath(0,folder,0,SHGFP_TYPE_CURRENT,@path[0])) then
     Result := path
   else
     Result := '';
end;

function GetAppdataFolder: string;
begin
   Result := GetSpecialFolderPath(CSIDL_APPDATA);
end;

procedure TSmsCreator_MainForm.FormCreate(Sender: TObject);
begin
  ReadIniF;
end;

procedure TSmsCreator_MainForm.ReadIniF;
var
  IniF : TIniFile;
  sDir : string;

begin
  sDir:= GetAppdataFolder;
  if sDir = '' then exit;
  if sDir[Length(sDir)] <> '\' then sDir:= sDir+'\';
  IniDir:= sDir+cIniDir;
  if not DirectoryExists(IniDir) then
    ForceDirectories(IniDir);
  IniF:= TInifile.Create(IniDir+cIniFile);
  try
    IniUser         := IniF.ReadString('main', 'user', '');
    IniPw           := IniF.ReadString('main', 'pw', '');
    IniRecipients   := IniF.ReadString('main', 'rec', '');
    IniCaption      := IniF.ReadString('main', 'cap', 'Test SMS');
    IniMsg          := IniF.ReadString('main', 'msg', 'Hello World');
    IniSender       := IniF.ReadString('main', 'send', 'Mr. Test');
    IniSimple       := IniF.ReadBool('main', 'simple', true);
  finally
    IniF.Free;
  end;
end;

procedure TSmsCreator_MainForm.FormShow(Sender: TObject);
begin

  User_Edit.Text:= IniUser;
  Pw_Edit.Text:= IniPw;
  Rec_Memo.Text:= IniRecipients;
  Caption_Edit.Text:= IniCaption;
  Sender_Edit.Text:= IniSender;
  Msg_Memo.Text:= IniMsg;
  Log_Memo.Clear;
  Simple_CB.Checked:= IniSimple;
  DoSimpleCheck;
end;

procedure TSmsCreator_MainForm.DoSimpleCheck;
begin
  Caption_Edit.Enabled:= not Simple_CB.Checked;
  Sender_Edit.Enabled:= not Simple_CB.Checked;
  if Simple_CB.Checked then
  begin
    Caption_Edit.Color:= $EAEAEA;
    Sender_Edit.Color:= $EAEAEA;
  end
  else
  begin
    Caption_Edit.Color:= clWhite;
    Sender_Edit.Color:= clWhite;
  end;
end;

procedure TSmsCreator_MainForm.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  WriteIniF;
end;

procedure TSmsCreator_MainForm.WriteIniF;
var
  IniF : TIniFile;

begin

  if not DirectoryExists(IniDir) then exit;

  IniF:= TInifile.Create(IniDir+cIniFile);
  try
    IniF.WriteString('main', 'user', User_Edit.Text);
    IniF.WriteString('main', 'pw', Pw_Edit.Text);
    IniF.WriteString('main', 'rec', Rec_Memo.Text);
    IniF.WriteString('main', 'cap', Caption_Edit.Text);
    IniF.WriteString('main', 'msg', Msg_Memo.Text);
    IniF.WriteString('main', 'send', Sender_Edit.Text);
    IniF.WriteBool('main', 'simple', IniSimple);
  finally
    IniF.Free;
  end;

end;

procedure TSmsCreator_MainForm.HTTPRIO1BeforeExecute(
  const MethodName: String; var SOAPRequest: WideString);
begin
  Log_Memo.Lines.Add('++++++++++++++++++++++++++++++++++++++++++++++++++++');
  DoAddLogMemo('SOAP-Request'+#13#10+SOAPRequest);
  Log_Memo.Lines.Add('----------------------------------------------------');
end;

procedure TSmsCreator_MainForm.HTTPRIO1AfterExecute(
  const MethodName: String; SOAPResponse: TStream);
var
  SL: TStringList;
begin
   Log_Memo.Lines.Add('++++++++++++++++++++++++++++++++++++++++++++++++++++');
   SoapResponse.Position := 0;
   SL:= TStringList.Create;
   try
     SL.LoadFromStream(SOAPResponse);
     DoAddLogMemo('SOAP-Response'+#13#10+SL.Text);
   finally
     SL.Free;
   end;
   Log_Memo.Lines.Add('----------------------------------------------------');
end;

procedure TSmsCreator_MainForm.DoAddLogMemo(sLog: string);
begin
  Log_Memo.Lines.Add(TimeToStr(Now)+' : '+sLog);
  while Log_Memo.Lines.Count > 1000 do
    Log_Memo.Lines.Delete(0);
end;

// SENDING

procedure TSmsCreator_MainForm.Test_ButtonClick(Sender: TObject);
var
  sResult: string;
begin

  try
    sResult:= (HTTPRIO1 as SendSoap).QueryBalance2(WideString(User_Edit.Text), WideString(Pw_Edit.Text));
    if Pos('ERROR', Uppercase(sResult)) = 0 then
    begin
      Status_Panel.Font.Color:= clLime;
      Status_Panel.Caption:= sResult;
    end
    else
    begin
      Status_Panel.Font.Color:= clRed;
      Status_Panel.Caption:= 'ERROR';
    end;
    DoAddLogMemo(sResult);
  except
      on E: Exception do
      begin
        DoAddLogMemo('General Error -' + E.Message);
        Status_Panel.Font.Color:= clRed;
        Status_Panel.Caption:= 'ERROR';
      end;
  end;

end;

procedure TSmsCreator_MainForm.Send_ButtonClick(Sender: TObject);
var
  sResult : string;
  sRec    : string;

begin

  sRec:= StringReplace(Rec_Memo.Text, ',', #13#10, [rfReplaceAll, rfIgnoreCase]);

  if IniSimple then
  begin

     try
      sResult:= (HTTPRIO1 as SendSoap).SendSimpleSMS(WideString(User_Edit.Text),
                                                     WideString(Pw_Edit.Text),
                                                     WideString(sRec),
                                                     WideString(Msg_Memo.Text),
                                                     );
      DoAddLogMemo('>>>>> send simple SMS : '+ sResult);
    except
        on E: Exception do
        begin
          DoAddLogMemo('General Error -' + E.Message);
        end;
    end;

  end
  else
  begin

    try
      sResult:= (HTTPRIO1 as SendSoap).SendText(WideString(User_Edit.Text),
                                                     WideString(Pw_Edit.Text),
                                                     WideString(Caption_Edit.Text),
                                                     WideString(Sender_Edit.Text),
                                                     WideString(sRec),
                                                     WideString(Msg_Memo.Text),
                                                     WideString('18'),
                                                     WideString(DateTimeToStr(Now))
                                                     );


      DoAddLogMemo('>>>>> send SMS : '+ sResult);
    except
        on E: Exception do
        begin
          DoAddLogMemo('General Error -' + E.Message);
        end;
    end;

  end;

end;

procedure TSmsCreator_MainForm.Simple_CBClick(Sender: TObject);
begin
  DoSimpleCheck;
end;

end.
